@@ -5,19 +5,16 @@ knitr::opts_chunk$set(fig.width=6, fig.height=4, fig.path='Figs/', fig.show='hol
 ## ----load_libraries, message=FALSE, warning=FALSE-----------------------------
 require(smooth)
 require(greybox)
-require(Mcomp)
 
 ## ----es_N2457-----------------------------------------------------------------
-es(M3$N2457$x, h=18, holdout=TRUE, silent=FALSE)
+ourModel <- es(BJsales, h=12, holdout=TRUE, silent=FALSE)
+ourModel
 
 ## ----es_N2457_with_interval---------------------------------------------------
-es(M3$N2457$x, h=18, holdout=TRUE, interval=TRUE, silent=FALSE)
-
-## ----es_N2457_save_model------------------------------------------------------
-ourModel <- es(M3$N2457$x, h=18, holdout=TRUE, silent="all")
+plot(forecast(ourModel, h=12, interval="prediction"))
 
 ## ----es_N2457_reuse_model-----------------------------------------------------
-es(M3$N2457$x, model=ourModel, h=18, holdout=FALSE, interval="np", level=0.93)
+es(BJsales, model=ourModel, h=12, holdout=FALSE)
 
 ## ----es_N2457_modelType-------------------------------------------------------
 modelType(ourModel)
@@ -26,37 +23,49 @@ modelType(ourModel)
 actuals(ourModel)
 
 ## ----es_N2457_reuse_model_parts-----------------------------------------------
-es(M3$N2457$x, model=modelType(ourModel), h=18, holdout=FALSE, initial=ourModel$initial, silent="graph")
-es(M3$N2457$x, model=modelType(ourModel), h=18, holdout=FALSE, persistence=ourModel$persistence, silent="graph")
+# Provided initials
+es(BJsales, model=modelType(ourModel),
+   h=12, holdout=FALSE,
+   initial=ourModel$initial)
+# Provided persistence
+es(BJsales, model=modelType(ourModel),
+   h=12, holdout=FALSE,
+   persistence=ourModel$persistence)
 
 ## ----es_N2457_set_initial-----------------------------------------------------
-es(M3$N2457$x, model=modelType(ourModel), h=18, holdout=FALSE, initial=1500, silent="graph")
+es(BJsales, model=modelType(ourModel),
+   h=12, holdout=FALSE,
+   initial=200)
 
 ## ----es_N2457_aMSTFE----------------------------------------------------------
-es(M3$N2457$x, h=18, holdout=TRUE, loss="aTMSE", bounds="a", ic="BIC", interval=TRUE)
+es(BJsales, h=12, holdout=TRUE, loss="MSEh", bounds="a", ic="BIC")
 
 ## ----es_N2457_combine---------------------------------------------------------
-es(M3$N2457$x, model="CCN", h=18, holdout=TRUE, silent="graph")
+es(BJsales, model="CCN", h=12, holdout=TRUE)
 
 ## ----es_N2457_pool------------------------------------------------------------
-es(M3$N2457$x, model=c("ANN","AAN","AAdN","ANA","AAA","AAdA"), h=18, holdout=TRUE, silent="graph")
-es(M3$N2457$x, model=c("CCC","ANN","AAN","AAdN","ANA","AAA","AAdA"), h=18, holdout=TRUE, silent="graph")
+# Select the best model in the pool
+es(BJsales, model=c("ANN","AAN","AAdN","MNN","MAN","MAdN"),
+   h=12, holdout=TRUE)
+# Combine the pool of models
+es(BJsales, model=c("CCC","ANN","AAN","AAdN","MNN","MAN","MAdN"),
+   h=12, holdout=TRUE)
 
 ## ----es_N2457_xreg_create-----------------------------------------------------
-x <- cbind(rnorm(length(M3$N2457$x),50,3),rnorm(length(M3$N2457$x),100,7))
+x <- BJsales.lead
 
 ## ----es_N2457_xreg------------------------------------------------------------
-es(M3$N2457$x, model="ZZZ", h=18, holdout=TRUE, xreg=x)
-
-## ----es_N2457_xreg_select-----------------------------------------------------
-es(M3$N2457$x, model="ZZZ", h=18, holdout=TRUE, xreg=x, xregDo="select")
+es(BJsales, model="ZZZ", h=12, holdout=TRUE,
+   xreg=x)
 
 ## ----es_N2457_xreg_expanded_select--------------------------------------------
-es(M3$N2457$x, model="ZZZ", h=18, holdout=TRUE, xreg=xregExpander(x), xregDo="select")
+es(BJsales, model="ZZZ", h=12, holdout=TRUE,
+   xreg=xregExpander(x), regressors="use")
 
-## ----es_N2457_xreg_formula----------------------------------------------------
-formula(ourModel)
+## ----es_N2457_xreg_select-----------------------------------------------------
+es(BJsales, model="ZZZ", h=12, holdout=TRUE,
+   xreg=xregExpander(x), regressors="select")
 
-## ----es_N2457_M3--------------------------------------------------------------
-es(M3$N2457, interval=TRUE, silent=FALSE)
+## ----es_N2457_M3, eval=FALSE--------------------------------------------------
+#  es(Mcomp::M3$N2457, silent=FALSE)
 
