@@ -6,23 +6,6 @@
 
 using namespace Rcpp;
 
-/* # Function allows to multiply polinomails */
-arma::vec polyMult(arma::vec const &poly1, arma::vec const &poly2){
-
-    int poly1Nonzero = arma::as_scalar(find(poly1,1,"last"));
-    int poly2Nonzero = arma::as_scalar(find(poly2,1,"last"));
-
-    arma::vec poly3(poly1Nonzero + poly2Nonzero + 1, arma::fill::zeros);
-
-    for(int i = 0; i <= poly1Nonzero; ++i){
-        for(int j = 0; j <= poly2Nonzero; ++j){
-            poly3(i+j) += poly1(i) * poly2(j);
-        }
-    }
-
-    return poly3;
-}
-
 /* # Function returns value of CDF-based likelihood function for the whole series */
 double cdf(arma::vec const &vecYt, arma::vec const &vecYfit, double const &errorSD, char const &E){
 
